@@ -14,12 +14,12 @@ import blark
 DESCRIPTION = __doc__
 
 
-MODULES = ('parse', )
+MODULES = ("parse", "format")
 
 
 def _try_import(module):
-    relative_module = f'.{module}'
-    return importlib.import_module(relative_module, 'blark')
+    relative_module = f".{module}"
+    return importlib.import_module(relative_module, "blark")
 
 
 def _build_commands():
@@ -34,14 +34,16 @@ def _build_commands():
             unavailable.append((module, ex))
         else:
             result[module] = (mod.build_arg_parser, mod.main)
-            DESCRIPTION += f'\n    $ blark {module} --help'
+            DESCRIPTION += f"\n    $ blark {module} --help"
 
     if unavailable:
-        DESCRIPTION += '\n\n'
+        DESCRIPTION += "\n\n"
 
         for module, ex in unavailable:
-            DESCRIPTION += (f'WARNING: blark {module!r} is unavailable due to:'
-                            f'\n\t{ex.__class__.__name__}: {ex}')
+            DESCRIPTION += (
+                f"WARNING: blark {module!r} is unavailable due to:"
+                f"\n\t{ex.__class__.__name__}: {ex}"
+            )
 
     return result
 
@@ -52,26 +54,29 @@ COMMANDS = _build_commands()
 def main():
     # Console entry point in setup.py
     top_parser = argparse.ArgumentParser(
-        prog='blark',
+        prog="blark",
         description=DESCRIPTION,
-        formatter_class=argparse.RawTextHelpFormatter
+        formatter_class=argparse.RawTextHelpFormatter,
     )
 
     top_parser.add_argument(
-        '--version', '-V',
-        action='version',
+        "--version",
+        "-V",
+        action="version",
         version=blark.__version__,
-        help="Show the blark version number and exit."
+        help="Show the blark version number and exit.",
     )
 
     top_parser.add_argument(
-        '--log', '-l', dest='log_level',
-        default='INFO',
+        "--log",
+        "-l",
+        dest="log_level",
+        default="INFO",
         type=str,
-        help='Python logging level (e.g. DEBUG, INFO, WARNING)'
+        help="Python logging level (e.g. DEBUG, INFO, WARNING)",
     )
 
-    subparsers = top_parser.add_subparsers(help='Possible subcommands')
+    subparsers = top_parser.add_subparsers(help="Possible subcommands")
     for command_name, (build_func, main) in COMMANDS.items():
         sub = subparsers.add_parser(command_name)
         build_func(sub)
@@ -79,19 +84,19 @@ def main():
 
     args = top_parser.parse_args()
     kwargs = vars(args)
-    log_level = kwargs.pop('log_level')
+    log_level = kwargs.pop("log_level")
 
-    logger = logging.getLogger('blark')
+    logger = logging.getLogger("blark")
     logger.setLevel(log_level)
     logging.basicConfig()
 
-    if hasattr(args, 'func'):
-        func = kwargs.pop('func')
-        logger.debug('%s(**%r)', func.__name__, kwargs)
+    if hasattr(args, "func"):
+        func = kwargs.pop("func")
+        logger.debug("%s(**%r)", func.__name__, kwargs)
         func(**kwargs)
     else:
         top_parser.print_help()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
